.. :changelog:

History
=======

1.0b2 (2017-06-16)
------------------

* Added helper function for getting cache hash keys of URLs.

1.0b1 (2017-04-26)
------------------

* Added optional value transformations.
* Added support for custom reducer callables.
* Added command-line option for scraping documents from local files.


1.0a2 (2017-04-04)
------------------

* Added support for Python 2.7.
* Fixed lxml support.

1.0a1 (2016-08-24)
------------------

* First release on PyPI.
